Ape Safe: Gnosis Safe tx builder
====================================

Ape Safe allows you to iteratively build complex multi-step Gnosis Safe transactions and safely preview their side effects from the convenience of a locally forked mainnet environment.

It is powered by Brownie_ and builds upon GnosisPy_, extending it with additional capabilities.
This tool has been informally known as Chief Multisig Officer at Yearn_ and has been used to prepare complex transactions with great success.

.. toctree::
   :maxdepth: 2

   intro
   quickstart
   install
   signing
   detailed
   useful
   changelog
   ape_safe


.. _Brownie: https://eth-brownie.readthedocs.io/en/latest/
.. _GnosisPy: https://github.com/gnosis/gnosis-py
.. _Yearn: https://github.com/yearn
